@@ -4,5 +4,5 @@ DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
 echo "DIR=$DIR"
 cd "$DIR/../../"
 rm -rfv FASTX-*
-mv experimental /tmp/_build_fastx_reader_exp
+mv experimental ../_build_fastx_reader_exp
 cd -
